@@ -6,7 +6,7 @@ use 5.010;
 
 use parent 'Class::Accessor';
 
-our $VERSION = '2.13';
+our $VERSION = '2.14';
 
 Travel::Routing::DE::EFA::Route::Part->mk_ro_accessors(
 	qw(arrival_platform arrival_stop
@@ -145,7 +145,7 @@ points, without interchanges
 
 =head1 VERSION
 
-version 2.13
+version 2.14
 
 =head1 DESCRIPTION
 
@@ -310,10 +310,9 @@ In those cases, B<train_destination> and B<train_line> are usually empty.
 
 =item $part->via
 
-List of stops passed between departure_stop and arrival_stop, as
-C<< [ "DD.MM.YYYY", "HH:MM", stop, platform ] >> hashrefs.
-
-May be empty, these are not always reported by efa.vrr.de.
+Returns a list of C<< [ "DD.MM.YYYY", "HH:MM", stop, platform ] >> arrayrefs
+encoding the stops passed between B<departure_stop> and B<arrival_stop>,
+if supported by the backend. Returns nothing / an empty list otherwise.
 
 =back
 
